@@ -19,7 +19,7 @@
  * @author Haruki Setoyama <haruki@planewave.org>
  * @copyright Copyright &copy; 2003-2004, Haruki SETOYAMA <haruki@planewave.org>
  * @license http://www.opensource.org/licenses/lgpl-license.php LGPL
- * @version 0.4 $Id: phpoot.parser.php,v 1.13 2004/03/04 12:02:30 haruki Exp $
+ * @version 0.4 $Id: phpoot.parser.php,v 1.15 2004/03/22 11:41:45 haruki Exp $
  * @link http://phpoot.sourceforge.jp/
  * @package phpoot
  * @subpackage _parser
@@ -48,13 +48,15 @@ class phpoot_handler {
 
     /**
      * option
+	 * <pre>
      * 'escape''remove'     when true, remove all the <! ... >
      * 'pi''remove'         when true, remove all the <? ... ?>
      * 'jasp''remove'       when true, remove all the <% ... %>
      * 'tag''empty'         names of empty tag which should be < /> style
      * 'tag''raw'           extention of model data with HTML.
      * 'tag''allow_no_brace'    variable name is normaly "{foo}" style. when true, allow just "foo"
-     * @var array
+     * </pre>
+	 * @var array
      */
     var $option = array(
             'tag' => array(
@@ -79,6 +81,7 @@ class phpoot_handler {
                 ),
                 'allow_no_brace' => false
             ),
+			'data' => array(),
             'escape' => array(
                 'remove' => false
             ),
@@ -732,7 +735,7 @@ class phpoot_parser_tag extends phpoot_parser {
             }
         }
 
-        if ($this->empty_tag == true) {
+        if ($this->_empty_tag == true) {
             $open_tag  .= ' />';
         } else {
             $open_tag  .= '>';
@@ -974,11 +977,11 @@ class phpoot_parser_tag_variable extends phpoot_parser_tag {
 class phpoot_parser_tag_num extends phpoot_parser_tag_static {
     function accept($open_tag, $attrs)
     {
-        if ($attrs[PHPOOT_VAR] == '{#num}') {
+        if (@$attrs[PHPOOT_VAR] == '{#num}') {
                 return true;
         }
         if ($this->_option['allow_no_brace'] == true
-        && $attrs[PHPOOT_VAR] == '#num') {
+        && @$attrs[PHPOOT_VAR] == '#num') {
                 return true;
         }
         return false;
