@@ -19,7 +19,7 @@
  * @author Haruki Setoyama <haruki@planewave.org>
  * @copyright Copyright &copy; 2003-2004, Haruki SETOYAMA <haruki@planewave.org>
  * @license http://www.opensource.org/licenses/lgpl-license.php LGPL
- * @version 0.4 $Id: phpoot.php,v 1.27 2004/03/04 12:43:56 haruki Exp $
+ * @version 0.4 $Id: phpoot.php,v 1.29 2004/03/22 11:36:11 haruki Exp $
  * @link http://phpoot.sourceforge.jp/
  * @package phpoot
  */
@@ -221,7 +221,7 @@ class phpoot extends PEAR {
         }
         if (! file_exists($compiled_file)) {
             $dir = dirname($compiled_file);
-            if (! $this->_mkdirs($dir, PHPOOT_DIR_MODE)) {
+            if (! $this->_mkdirs($dir)) {
                 return "Fail to create the directory '$dir' for compiled files.";
             }
             if (! is_writable($dir)) {
@@ -451,10 +451,10 @@ function phpoot_attr($attr, $val, $var)
         return '';
     } elseif ($target === true) {
         return " $attr=\"$attr\"";
-    } elseif (! is_string($target)) {
-        return '';
-    } else {
+    } elseif (is_string($target) || is_numeric($target)) {
         return ' ' . $attr . '="' . phpoot_htmlspecialchars($target) . '"';
+    } else {
+        return '';
     }
 }
 
